Coverage for jbank/apps.py: 100%

# Coverage for jbank/apps.py : 100%

## 6 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 from django.apps import AppConfig

2 from django.utils.translation import gettext_lazy as _

3

4

5 class JbankConfig(AppConfig):

6 name = "jbank"

7 verbose_name = _("Bank Integration")

8 default_auto_field = "django.db.models.AutoField"